#
# spec file for package timoni
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           timoni
Version:        0.13.1
Release:        1.1
Summary:        Package manager for Kubernetes, powered by CUE and inspired by Helm
License:        Apache-2.0
URL:            https://github.com/stefanprodan/timoni
Source:         timoni-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.20

%description
Timoni is a package manager for Kubernetes, powered by CUE and inspired by Helm.

The Timoni project strives to improve the UX of authoring Kubernetes configs. Instead of mingling Go templates with YAML like Helm, or layering YAML on top of each-other like Kustomize, Timoni relies on cuelang's type safety, code generation and data validation features to offer a better experience of creating, packaging and delivering apps to Kubernetes.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.VERSION=%{version}" \
   -o bin/timoni ./cmd/timoni

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Mon Sep 11 2023 kastl@b1-systems.de
- Update to version 0.13.1:
  * bundle: Fix values merge with module defaults
* Mon Sep 11 2023 kastl@b1-systems.de
- Update to version 0.13.0:
  * docs: Add Nix installation instructions
  * ci: Push and sign minimal module Publish signed (cosign
    keyless) module to `oci://ghcr.io/stefanprodan/timoni/minimal`
  * docs: Signing modules with Cosign - add signing with Cosign
    static keys and keyless to module publishing docs - add Cosign
    Keyless example to the GitHub Actions docs
  * Add cosign signing and verification for modules (#182)
  * Enforce Kubernetes min version for modules
  * Use Go 1.21 stdlib
  * Add tests for the runtime flag
  * Add the runtime flag to bundle cmd
  * Decode Secret data from base64
  * Add bundle runtime documentation
  * Replace `@timoni(env)` with `@timoni(runtime)` Make reading env
    vars an opt-in feature `timoni bundle --runtime-from-env`
  * Introduce the Runtime API
  * Prefix Kubernetes flags Add `kube-` prefix to all the flags
    specific to Kubernetes to avoid collision with OCI registry.
  * Add a YAML CRD to CUE IR conversion function
  * Bump github.com/cyphar/filepath-securejoin from 0.2.3 to 0.2.4
* Tue Sep  5 2023 kastl@b1-systems.de
- Update to version 0.12.1:
  * Fix panic when waiting for global resources
* Tue Sep  5 2023 kastl@b1-systems.de
- Update to version 0.12.0:
  * Update example modules
  - podinfo v6.4.1
  - redis v7.2.0
  - minimal v0.1.0
  * Mark image fields as required Use CUE 0.6 required fields
    feature for better error messages when required fields are
    missing from values.
  * Build with Go 1.21
  * Bump the ci group with 2 updates
  * Run server-side apply operations in parallel Speed up the
    Kubernetes resources reconciliation by running the server-side
    apply operations in parallel.
  * Set standard Kubernetes labels: app name and version
  * Use metadata abstraction in the module template
  * Introduce Kubernetes metadata CUE definition
  * Inject version info Add optional tags to inject the module
    version and Kubernetes version at runtime.
  * Update `cuelang.org/go` to v0.6.0
  * Bump the ci group with 3 updates
  * Document how to change the apply behaviour
  * Add support for one-off resources To apply resources only if
    they don't exist on the cluster, module authors can annotate
    them with `action.timoni.sh/one-off: "enabled"`.
  * Update dependencies
  * Bump the ci group with 2 updates
* Tue Aug  1 2023 kastl@b1-systems.de
- Update to version 0.11.1:
  * Fail fast when waiting for resources
  * Update dependencies
  - k8s.io/* v0.27.4
  - github.com/fluxcd/pkg/oci v0.30.0
  - github.com/fluxcd/pkg/ssa v0.29.0
  - github.com/homeport/dyff v1.5.8
  - github.com/rs/zerolog v1.30.0
* Mon Jul 24 2023 kastl@b1-systems.de
- Update to version 0.11.0:
  * test: add get instance case
  * test: add quoted instance test
  * fix: unquote instance name
  * Update the module structure doc to match minimal
  * Publish init module to `ghcr.io/stefanprodan/timoni/minimal`
  * Add healthz endpoint
  * Use minimal module for `timoni mod init`
  * Add minimal module example
  * Update Redis to 7.0.12 and use image digest
  * Add local dev setup
  * Fix bundle build test flake Reset flags to avoid test failures
    of `timoni bundle build`
  * Bump the ci group with 2 updates
  * Colorize bundle lint
  * Colorize status
  * Added missing 'return if err' check
  * Added coloring to inspect resources
  * Changed to use color.Output & color.Error
  * Refactored colorize
  * Prettier and more colorized output
  * Added completion on installed instances & --namespace
  * Add stale resources to the dry run output
* Sat Jul  8 2023 kastl@b1-systems.de
- Update to version 0.10.0:
  * ci: Pin cuelang version to v0.5.0
  * ci: Enable dependabot grouping
  * Normalise the SLSA provenance files
  * Document how to build bundles from JSON/YAML
  * test: add bundle files test
  * feat: add json support
  * feat: add yaml support for bundles
  * Bump anchore/sbom-action from 0.14.2 to 0.14.3
* Fri Jun 23 2023 kastl@b1-systems.de
- Update to version 0.9.0:
  * Enabled reproducible builds of OCI artifacts Use the source
    date epoch (recommend by reproducible-builds.org) to set the
    OCI artifact created timestamp. The source date is extracted
    from Git metadata and requires the `git` CLI to be in PATH.
    This ensures that `timoni mod push` will generate an artifact
    with the same digest, if run multiple times on the same checked
    out commit.
  * Update dependencies
  * Add support for env var injection in bundles
  * Bump goreleaser/goreleaser-action from 4.2.0 to 4.3.0
  * Bump slsa-framework/slsa-github-generator from 1.6.0 to 1.7.0
  * Bump actions/checkout from 3.5.2 to 3.5.3
  * Bump github/codeql-action from 2.3.6 to 2.13.4
  * Bump github/codeql-action from 2.3.5 to 2.3.6
  * Add env injector to CUE engine
  * docs: Normalise page titles
  * Add Helm comparison to docs
* Mon May 29 2023 kastl@b1-systems.de
- Update to version 0.8.2:
  * Merge the bundle values with the module defaults
* Mon May 29 2023 kastl@b1-systems.de
- Update to version 0.8.1:
  * Add CUE version to `timoni version` output
  * Map the timeout flag to apply wait operations
  * Bump github/codeql-action from 2.3.3 to 2.3.5
* Mon May 29 2023 kastl@b1-systems.de
- Update to version 0.8.0:
  * Increase default timeout to 5m
  * Add spinner to long-running operations
  * Pass logger via command context
  * Add pretty print for logs and diff output
  * Update dependencies to Kubernetes 1.27
  * update cue to v0.5.0
  * Bump helm/kind-action from 1.5.0 to 1.7.0
  * Bump actions/setup-go from 4.0.0 to 4.0.1
  * Document SLSA Provenance & SBOMs
* Tue May 16 2023 kastl@b1-systems.de
- Update to version 0.7.1:
  * Generate SLSA3+ Provenance
* Tue May 16 2023 kastl@b1-systems.de
- Update to version 0.7.0:
  * Add security policy Explain how to report a vulnerability and
    how we handle vulnerability disclosures for the Timoni project.
  * test: bundle build cmd
  * docs: bundle build cmd
  * feat: add bundle build command
  * Bump github.com/docker/distribution
* Thu May 11 2023 kastl@b1-systems.de
- Update to version 0.6.0:
  * Fix apply dry-run for new namespaces
  * Add `timoni.ignore` to module documentation
  * Add support for `timoni.ignore` - Allow defining ignore patters
    with `timoni.ignore` (same format as `.gitignore`) - Add a
    default ignore file to `timoni mod init` - Exclude ignored
    files and directories when pushing modules to registry - Load
    `timoni.ignore` when performing operations with local modules
  * Bump anchore/sbom-action from 0.14.1 to 0.14.2
  * Bump github/codeql-action from 2.3.2 to 2.3.3
* Thu May  4 2023 kastl@b1-systems.de
- Update to version 0.5.0:
  * Update example modules and bundles
  - bump podinfo to 6.3.6
  - bump redis to 7.0.11
  * Target all namespaces when deleting a named bundle
  * Implement native linting
  * Enforce instance schema validation
  * Add instance schema to API
  * Enable name-oriented bundle management
  * Bump github/codeql-action from 2.2.12 to 2.3.2
  * Ensure all CUE build errors are printed
  * Improve how `GetResource` works
  * Bump github/codeql-action from 2.2.11 to 2.2.12
  * Bump actions/checkout from 3.5.0 to 3.5.2
  * Add force upgrade option to bundle docs
  * Add a bundle example to quickstart
  * Correct target of mod push doc link
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.4.0:
  * Document how bundles work
  * Implement delete command for bundles
  * Add bundle test for digest and latest version
  * Add bundle tests for module digest
  * Refactor bundle apply
  - use BundleBuilder to validate and extract instances
  - allow pinning a module by its OCI digest
  - pull latest module when the version and digest are not
    specified
  - when both the module version and the digest are specified,
    error out if the OCI digest of the version doesn't match the
    specified digest
  * Use the bundle builder for linting
  * Add bundle builder to engine The BundleBuilder compiles CUE
    definitions to Go Bundle objects, and extracts and validates
    instances.
  * Fetch module by OCI digest
  * Add digest optional field to Bundle API
  * Implement listing command for module versions The `timoni mod
    list oci://<module-url>` command prints a table with a module's
    versions and their OCI digests.
  * Bump github/codeql-action from 2.2.9 to 2.2.11
  * Add Arkade install method
  * Add image digest to examples
  * Bump redis to 7.0.10
  * Bump podinfo to 6.3.5
  * Document module publishing and versioning
  * Bump github.com/docker/docker
* Thu Apr  6 2023 Johannes Kastl <kastl@b1-systems.de>
- new package timoni: package manager for Kubernetes, powered by
  CUE and inspired by Helm
